.. :changelog:

History
-------

0.1.0 (2017-12-03)
++++++++++++++++++

* First release on PyPI.
* Initial models and REST API.

0.2.0 (2017-12-11)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-genomix-users/compare/v0.1.0...v0.2.0>`_

* Added Profile.
* Added ability to sync profile from LDAP.

0.3.0 (2017-01-05)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-genomix-users/compare/v0.2.0...v0.3.0>`_

* Added REST API filters.

0.3.1 (2017-01-12)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-genomix-users/compare/v0.3.0...v0.3.1>`_

* Fixed route names for SimpleRouter

0.4.0 (2017-02-09)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-genomix-users/compare/v0.3.1...v0.4.0>`_

* Updated requirements to latest

0.5.0 (2017-04-07)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-genomix-users/compare/v0.4.0...v0.5.0>`_

* Added support for Django 2.0 and Python 3.6
* Dropped support for Django < 1.11 and Python 2.7, 3.3, 3.4

0.5.1 (2017-04-10)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-genomix-users/compare/v0.5.0...v0.5.1>`_

* Fixed issue with Admin registration.  From now on - users can import and use this in their apps

0.5.2 (2017-04-18)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-genomix-users/compare/v0.5.1...v0.5.2>`_

* Updated 3rd party libs


0.5.3 (2018-05-16)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-genomix-users/compare/v0.5.2...v0.5.3>`_

* Updated setup.py to read install_requires from requirements.txt
